# pysquare
Its take an integer ang gives it square.

## Installation
'''pip install pysquare'''

## How to use it?
Open terminal and type square and then input the integer

## License
© 2021 Saurabh Sahani

Tis repositary is licensed under MIT license.
